@@ -6,7 +6,7 @@
 #
 
 package File::ByLine;
-$File::ByLine::VERSION = '1.182362'; # TRIAL
+$File::ByLine::VERSION = '1.192450'; # TRIAL
 use v5.10;
 
 # ABSTRACT: Line-by-line file access loops
@@ -196,7 +196,7 @@ File::ByLine - Line-by-line file access loops
 
 =head1 VERSION
 
-version 1.182362
+version 1.192450
 
 =head1 SYNOPSIS
 
@@ -260,7 +260,7 @@ version 1.182362
 
   # Skip the header line
   my $byline = File::ByLine->new();
-  $byline->skip_header(1);
+  $byline->header_skip(1);
   $byline->do( sub { foo($_) }, "file.txt");
   my (@grep_result) = $byline->grep( sub { m/foo/ }, "file.txt");
   my (@map_result)  = $byline->map( sub { lc($_) }, "file.txt");
@@ -800,10 +800,9 @@ someone appreciates your work!
 I don't seek any money for this - I do this work because I enjoy it.  That
 said, should you want to show appreciation financially, few things would make
 me smile more than knowing that you sent a donation to the Gender Identity
-Center of Colorado (See L<http://giccolorado.org/> and donation page
-at L<https://tinyurl.com/giccodonation>).  This organization understands
-TIMTOWTDI in life and, in line with that understanding, provides life-saving
-support to the transgender community.
+Center of Colorado (See L<http://giccolorado.org/>.  This organization
+understands TIMTOWTDI in life and, in line with that understanding, provides
+life-saving support to the transgender community.
 
 =head1 AUTHOR
 
